==> nextcloud-30.0.5.tgz: nextcloud/apps/twofactor_nextcloud_notification/l10n/de_DE.js <==
OC.L10N.register(
    "twofactor_nextcloud_notification",
    {
    "TwoFactor Nextcloud notification" : "Zwei-Faktor Nextcloud-Benachrichtigung",
    "Approve" : "Bestätigen",
    "Cancel" : "Abbrechen",
    "Login attempt from IP address {ip}" : "Anmeldeversuch von IP-Adresse {ip}",
    "If you are currently trying log in from another device or browser please approve the request. If you are not trying to log in at the moment, you should use the cancel option to abort the login attempt." : "Wenn Sie gerade versuchen, sich von einem anderen Gerät oder Browser aus anzumelden, genehmigen Sie bitte die Anfrage. Wenn Sie gerade nicht versuchen, sich anzumelden, sollten Sie die Abbruchoption verwenden, um den Anmeldeversuch abzubrechen.",
    "Nextcloud Notification" : "Nextcloud-Benachrichtigung",
    "Authenticate using a device that is already logged in to your account" : "Authentifizieren Sie sich über ein Gerät, das bereits mit Ihrem Konto verbunden ist",
    "Two-Factor Authentication via Nextcloud notification" : "Zwei-Faktor-Authentifizierung mittels Nextcloud-Benachrichtigungen",
    "Allows using any of your logged in devices as second factor" : "Ermöglicht ein an der Nextcloud angemeldetes Gerät als zweiten Faktior zu benutzen.",
    "Please accept the request on one of your logged in devices." : "Bitte akzeptieren Sie die Anfrage auf einem Ihrer eingeloggten Gerät",
    "You will be redirected automatically once this login has been accepted." : "Nach Bestätigung dieses Anmeldeversuches werden Sie automatisch weitergeleitet",
    "Please wait …" : "Bitte warten …",
    "Your login attempt was rejected." : "Ihr Anmeldeversuch wurde zurückgewiesen.",
    "Use two-factor authentication via Nextcloud notifications" : "Zwei-Faktor-Authentifizierung mittels Nextcloud-Benachrichtigungen benutzen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.10.tgz: nextcloud/apps/twofactor_nextcloud_notification/l10n/de_DE.js <==
OC.L10N.register(
    "twofactor_nextcloud_notification",
    {
    "TwoFactor Nextcloud notification" : "Zwei-Faktor Nextcloud-Benachrichtigung",
    "Approve" : "Bestätigen",
    "Cancel" : "Abbrechen",
    "Login attempt from IP address {ip}" : "Anmeldeversuch von IP-Adresse {ip}",
    "If you are currently trying log in from another device or browser please approve the request. If you are not trying to log in at the moment, you should use the cancel option to abort the login attempt." : "Wenn Sie gerade versuchen, sich von einem anderen Gerät oder Browser aus anzumelden, genehmigen Sie bitte die Anfrage. Wenn Sie gerade nicht versuchen, sich anzumelden, sollten Sie die Abbruchoption verwenden, um den Anmeldeversuch abzubrechen.",
    "Nextcloud Notification" : "Nextcloud-Benachrichtigung",
    "Authenticate using a device that is already logged in to your account" : "Authentifizieren Sie sich über ein Gerät, das bereits mit Ihrem Konto verbunden ist",
    "Two-Factor Authentication via Nextcloud notification" : "Zwei-Faktor-Authentifizierung mittels Nextcloud-Benachrichtigungen",
    "Allows using any of your logged in devices as second factor" : "Ermöglicht ein an der Nextcloud angemeldetes Gerät als zweiten Faktior zu benutzen.",
    "Please accept the request on one of your logged in devices." : "Bitte akzeptieren Sie die Anfrage auf einem Ihrer eingeloggten Geräte.",
    "You will be redirected automatically once this login has been accepted." : "Nach Bestätigung dieses Anmeldeversuches werden Sie automatisch weitergeleitet.",
    "Please wait …" : "Bitte warten …",
    "Your login attempt was rejected." : "Ihr Anmeldeversuch wurde zurückgewiesen.",
    "Use two-factor authentication via Nextcloud notifications" : "Zwei-Faktor-Authentifizierung mittels Nextcloud-Benachrichtigungen benutzen"
},
"nplurals=2; plural=(n != 1);");
